#
# Conditional build:
# - protocols
%bcond_without	bittorrent	# BitTorrent protocol support
%bcond_without	fsp		# FSP support
%bcond_without	idn		# Internation Domain Names support
%bcond_without	ipv6		# IPv6 support
%bcond_with	smb		# smb protocol support (non-distib: recent libsmbclient is GPL v3)
%bcond_with	gnutls		# GNUTLS-based SSL support (instead of openssl)
%bcond_without	openssl		# OpenSSL-based SSL support
# - content
%bcond_without	cgi		# Local CGI support
%bcond_without	brotli		# Brotli compression support
%bcond_without	js		# experimental (yet quite usable) JavaScript support (using quickjs)
%bcond_with	lzma		# LZMA support (old API, incompatible with xz-libs)
%bcond_without	zstd	# zstd compression support
# - scripting
%bcond_with	guile		# Guile scripting support (non-distrib: guile 2 is LGPL v3+)
%bcond_without	lua		# Lua scripting
%bcond_with	perl		# Perl scripting
%bcond_with	python		# Python scripting support
%bcond_with	ruby		# (experimental) Ruby scripting support
# - display and UI
%bcond_without	256		# 256 colors support
%bcond_without	led		# LEDs
%bcond_without	truecolor	# true color
%bcond_with	x		# Use the X Window System
# - misc
%bcond_without	verbose		# verbose build (V=1)
%bcond_without	libevent	# build without libevent

%if %{with gnutls}
%undefine	with_openssl
%endif

Summary:	Experimantal Links (text WWW browser)
Summary(es.UTF-8):	El links es un browser para modo texto, similar a lynx
Summary(pl.UTF-8):	Eksperymentalny Links (tekstowa przeglądarka WWW)
Summary(pt_BR.UTF-8):	O links é um browser para modo texto, similar ao lynx
Name:		elinks
Version:	0.15.1
Release:	1
Epoch:		1
License:	GPL v2
Group:		Applications/Networking
Source0:	https://github.com/rkd77/elinks/releases/download/v%{version}/%{name}-%{version}.tar.xz
# Source0-md5:	9bf8aad8d480139b9420c19f18ae9a4e
Source1:	%{name}.desktop
Source2:	links.png
URL:		http://www.elinks.cz/
BuildRequires:	autoconf >= 2.61
BuildRequires:	automake
BuildRequires:	bzip2-devel
BuildRequires:	expat-devel
%{?with_fsp:BuildRequires:	fsplib-devel}
BuildRequires:	gettext-tools
BuildRequires:	git-core
%{?with_gnutls:BuildRequires:	gnutls-devel >= 1.2.5}
BuildRequires:	gpm-devel
%{?with_guile:BuildRequires: guile-devel}
BuildRequires:	libstdc++-devel
%{?with_js:BuildRequires:	libxml++5-devel >= 5.0.1-2}
BuildRequires:	rpmbuild(macros) >= 1.736
%{?with_js:BuildRequires:	sqlite3-devel}
%{?with_brotli:BuildRequires:	libbrotli-devel}
%{?with_libevent:BuildRequires:	libevent-devel}
%{?with_idn:BuildRequires:	libidn-devel}
%{?with_smb:BuildRequires:	libsmbclient-devel}
%{?with_lua:BuildRequires:	lua53-devel}
%{?with_lzma:BuildRequires:	lzma-devel}
BuildRequires:	meson
BuildRequires:	ncurses-devel >= 5.1
BuildRequires:	ninja >= 1.5
%{?with_openssl:BuildRequires:	openssl-devel >= 0.9.7d}
%{?with_perl:BuildRequires:	perl-devel}
BuildRequires:	pkgconfig
%{?with_python:BuildRequires:	python3-devel}
%{?with_js:BuildRequires:	quickjs-devel >= 20210327-4}
%{?with_ruby:BuildRequires:	ruby-devel}
BuildRequires:	sed
BuildRequires:	tar >= 1:1.22
BuildRequires:	tre-devel
BuildRequires:	which
BuildRequires:	xz
BuildRequires:	zlib-devel
%{?with_zstd:BuildRequires:	zstd-devel}
Suggests:	mailcap
Provides:	webclient
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		_sysconfdir	/etc/elinks
%define		specflags_ia32	-fomit-frame-pointer

%description
This is the elinks tree - intended to provide feature-rich version of
links, however not rock-stable and dedicated mainly for testing. Its
purpose is to make alternative to links, until Mikulas will have some
time to maintain it, and to test and tune various patches for Mikulas
to be able to include them in the official links releases.

%description -l es.UTF-8
Links es un browser WWW modo texto, similar al Lynx. El links muestra
tablas, hace baja archivos en segundo plano, y usa conexiones HTTP/1.1
keepalive.

%description -l pl.UTF-8
Bogata w opcje i możliwości wersja tekstowej przeglądarki WWW - links.
elinks jednak jest dedykowana głównie do testowania.

%description -l pt_BR.UTF-8
Links é um browser WWW modo texto, similar ao Lynx. O Links exibe
tabelas, baixa arquivos em segundo plano, e usa as conexões HTTP/1.1
keepalive.

%prep
%setup -q

%build
%meson build \
	%{?with_bittorrent:-Dbittorrent=true} \
	%{?with_cgi:-Dcgi=true} \
	-D88-colors=true \
	%{?with_256:-D256-colors=true} \
	%{?with_truecolor:-Dtrue-color=true} \
	-Dexmode=true \
	%{?debug:-Ddebug=true} \
	%{!?debug:-Dfastmem=true} \
	-Dfinger=true \
	-Dfsp=%{__true_false fsp} \
	-Dgemini=true \
	-Dgettext=true \
	-Dgopher=true \
	-Dhtml-highlight=true \
	%{!?with_ipv6:-Dipv6=false} \
	%{?with_leds:-Dleds=true} \
	-Dmarks=true \
	-Dnntp=true \
	-Dno-root=false \
	%{?with_smb:-Dsmb=true} \
	%{?with_brotli:-Dbrotli=true} \
	%{?with_zstd:-Dzstd=true} \
	%{?with_gnutls:-Dgnutls=true} \
	%{?with_guile:-Dguile=true} \
	%{!?with_idn:-Didn=false} \
	%{?with_lua:-Dluapkg=lua5.3} \
	%{?with_lzma:-Dlzma=true} \
	%{?with_openssl:-Dopenssl=true} \
	%{?with_perl:-Dperl=true} \
	%{?with_python:-Dpython=true} \
	%{?with_ruby:-Druby=true} \
	%{?with_js:-Dquickjs=true} \
	%{?with_x:-Dx=true} \
	%{?with_libevent:-Dlibevent=true}

%ninja_build -C build

%install
rm -rf $RPM_BUILD_ROOT
%ninja_install -C build

install -d $RPM_BUILD_ROOT%{_desktopdir} \
	$RPM_BUILD_ROOT%{_datadir}/%{name} \
	$RPM_BUILD_ROOT{%{_sysconfdir},%{_pixmapsdir}}

cp -a %{SOURCE1} $RPM_BUILD_ROOT%{_desktopdir}
cp -a %{SOURCE2} $RPM_BUILD_ROOT%{_pixmapsdir}/%{name}.png

%{?with_lua:install contrib/lua/*.lua $RPM_BUILD_ROOT%{_sysconfdir}}
sed -i -e 's|bin/lua|bin/lua5.3|g' $RPM_BUILD_ROOT%{_sysconfdir}/*lua

%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT

%files -f %{name}.lang
%defattr(644,root,root,755)
%doc AUTHORS BUGS ChangeLog NEWS README SITES TODO
%doc contrib/{keybind*,wipe-out-ssl*,lua/elinks-remote} contrib/conv/{*awk,*.pl,*.sh}
%attr(755,root,root) %{_bindir}/elinks
%{_mandir}/man1/elinks.1*
%{_mandir}/man5/elinks.conf.5*
%{_mandir}/man5/elinkskeys.5*
%{_desktopdir}/elinks.desktop
%{_pixmapsdir}/elinks.png
%if %{with lua}
%dir %{_sysconfdir}
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/*.lua
%endif
%changelog
* Thu Aug 04 2022 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/elinks.git;a=log;h=master

* Sun Jul 31 2022 Witold Filipczyk <witekfl@poczta.onet.pl> 7ba08f7
- updated to 0.15.1

* Fri Jun 17 2022 Krzysztof Mrozowicz <mrozowik@pld-linux.org> 261ce4d
- BR: git-core

* Sat Jun 04 2022 Witold Filipczyk <witekfl@poczta.onet.pl> 5f8650b
- enable libevent by default
  (there is weird bug related to select call on x32). libevent is better here
- rel 2

* Sun May 22 2022 Jakub Bogusz <qboosh@pld-linux.org> fbbf087
- sorted BRs, requires also libstdc++-devel

* Sun Feb 27 2022 Jan Palus <atler@pld-linux.org> ea719f7
- explicitly enable/disable fsp support

* Sun Feb 27 2022 Jan Palus <atler@pld-linux.org> fadd03e
- remove typeahead-beginning and js187 patches dropped from spec in 612abce

* Sun Feb 27 2022 Jan Palus <atler@pld-linux.org> 742dfa9
- BRs for tar.xz source

* Sun Feb 27 2022 Jan Palus <atler@pld-linux.org> aca21fe
- BR: ninja; macros for %ninja*

* Sun Feb 20 2022 Jan Rękorajski <baggins@pld-linux.org> 1d73e99
- bump quickjs BR to properly packaged version

* Sat Dec 25 2021 Witold Filipczyk <witekfl@poczta.onet.pl> 612abce
- updated to 0.15.0
- some patches aplied upstream
- added options document.browse.search.beginning_only
  document.browse.search.ignore_history
  ui.double_esc have functionality from patches
- js is unusable in this version, so better disable it
  or do not compile in at all

* Fri Sep 24 2021 Jan Rękorajski <baggins@pld-linux.org> a04ac09
- rebuild with openssl 3.0.0

* Sun May 09 2021 Jan Rękorajski <baggins@pld-linux.org> c358677
- use unversioned system lua and fix build against lua 5.3+
- rel 7

* Fri May 07 2021 Jan Rękorajski <baggins@pld-linux.org> 212ef37
- rebuild with perl 5.32

* Fri May 07 2021 Jan Rękorajski <baggins@pld-linux.org> 9798e93
- rediff patches

* Tue May 05 2020 Jan Palus <atler@pld-linux.org> 3e69115
- refresh config.sub

* Wed Dec 04 2019 Jan Rękorajski <baggins@pld-linux.org> febe950
- rebuild with perl 5.30.0
- release 5 (by relup.sh)

* Fri Nov 23 2018 Jan Rękorajski <baggins@pld-linux.org> d4297c2
- rebuild with libidn 1.35
- release 4 (by relup.sh)

* Thu Oct 25 2018 Jan Rękorajski <baggins@pld-linux.org> 2aa4674
- build with js187 so we can build it on x32 with javascript support
- rel 3

* Sat Sep 15 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> d819e8b
- release 2 (by relup.sh)

* Sat Sep 01 2018 Jakub Bogusz <qboosh@pld-linux.org> 8c08d91
- update to todays snapshot (last change 20170723)

